from __future__ import unicode_literals

from pybtex.bibtex.interpreter import (
    FunctionLiteral, Identifier, Integer, QuotedVar, String
)

bst = [[u'ENTRY',
  [Identifier(u'address'),
   Identifier(u'author'),
   Identifier(u'booktitle'),
   Identifier(u'chapter'),
   Identifier(u'edition'),
   Identifier(u'editor'),
   Identifier(u'howpublished'),
   Identifier(u'institution'),
   Identifier(u'isbn'),
   Identifier(u'issn'),
   Identifier(u'journal'),
   Identifier(u'key'),
   Identifier(u'language'),
   Identifier(u'month'),
   Identifier(u'note'),
   Identifier(u'number'),
   Identifier(u'organization'),
   Identifier(u'pages'),
   Identifier(u'publisher'),
   Identifier(u'school'),
   Identifier(u'series'),
   Identifier(u'title'),
   Identifier(u'type'),
   Identifier(u'volume'),
   Identifier(u'year'),
   Identifier(u'url'),
   Identifier(u'urldate'),
   Identifier(u'volumetitle'),
   Identifier(u'dissyear'),
   Identifier(u'howcited'),
   Identifier(u'juratitle'),
   Identifier(u'juraauthor'),
   Identifier(u'shorttitle'),
   Identifier(u'shortauthor'),
   Identifier(u'ssedition'),
   Identifier(u'titleaddon'),
   Identifier(u'booktitleaddon'),
   Identifier(u'editortype'),
   Identifier(u'sortkey'),
   Identifier(u'annote'),
   Identifier(u'gender'),
   Identifier(u'translator'),
   Identifier(u'flanguage'),
   Identifier(u'oyear'),
   Identifier(u'oaddress'),
   Identifier(u'opublisher'),
   Identifier(u'updated'),
   Identifier(u'totalpages'),
   Identifier(u'founder'),
   Identifier(u'archive'),
   Identifier(u'subarchive'),
   Identifier(u'shortarchive'),
   Identifier(u'shortsubarchive'),
   Identifier(u'sig1'),
   Identifier(u'sig2'),
   Identifier(u'sig3'),
   Identifier(u'sig4'),
   Identifier(u'archname')],
  [Identifier(u'repeat-authors'), Identifier(u'repeat-titles')],
  [Identifier(u'label'),
   Identifier(u'dummy.label'),
   Identifier(u'extra.label'),
   Identifier(u'sort.label'),
   Identifier(u'current-authors')]],
 [u'INTEGERS',
  [Identifier(u'output.state'),
   Identifier(u'before.all'),
   Identifier(u'mid.sentence'),
   Identifier(u'after.sentence'),
   Identifier(u'after.block')]],
 [u'INTEGERS', [Identifier(u'colon.after'), Identifier(u'period.dash')]],
 [u'FUNCTION',
  [Identifier(u'init.state.consts')],
  [Integer(0),
   QuotedVar(u'before.all'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'mid.sentence'),
   Identifier(u':='),
   Integer(2),
   QuotedVar(u'after.sentence'),
   Identifier(u':='),
   Integer(3),
   QuotedVar(u'after.block'),
   Identifier(u':='),
   Integer(4),
   QuotedVar(u'colon.after'),
   Identifier(u':='),
   Integer(5),
   QuotedVar(u'period.dash'),
   Identifier(u':=')]],
 [u'STRINGS',
  [Identifier(u's'),
   Identifier(u't'),
   Identifier(u'u'),
   Identifier(u'v'),
   Identifier(u'w'),
   Identifier(u'x')]],
 [u'FUNCTION',
  [Identifier(u'output.nonnull')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Identifier(u'output.state'),
   Identifier(u'after.block'),
   Identifier(u'='),
   FunctionLiteral([Identifier(u'write$')]),
   FunctionLiteral([Identifier(u'output.state'), Identifier(u'before.all'), Identifier(u'='), FunctionLiteral([Identifier(u'write$')]), FunctionLiteral([Identifier(u'output.state'), Identifier(u'colon.after'), Identifier(u'='), FunctionLiteral([String(u''), Identifier(u'*'), Identifier(u'write$')]), FunctionLiteral([Identifier(u'output.state'), Identifier(u'period.dash'), Identifier(u'='), FunctionLiteral([String(u', '), Identifier(u'*'), Identifier(u'write$')]), FunctionLiteral([Identifier(u'output.state'), Identifier(u'mid.sentence'), Identifier(u'='), FunctionLiteral([String(u' '), Identifier(u'*'), Identifier(u'write$')]), FunctionLiteral([Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'after.block'), QuotedVar(u'output.state'), Identifier(u':=')]),
   Identifier(u'if$'),
   Identifier(u's')]],
 [u'FUNCTION',
  [Identifier(u'output')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   QuotedVar(u'pop$'),
   QuotedVar(u'output.nonnull'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'output.check')],
  [QuotedVar(u't'),
   Identifier(u':='),
   Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'Empty '), Identifier(u't'), Identifier(u'*'), String(u' in '), Identifier(u'*'), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]),
   QuotedVar(u'output.nonnull'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'not')],
  [FunctionLiteral([Integer(0)]),
   FunctionLiteral([Integer(1)]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'and')],
  [QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'pop$'), Integer(0)]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'or')],
  [FunctionLiteral([Identifier(u'pop$'), Integer(1)]),
   QuotedVar(u'skip$'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'is.num')],
  [Identifier(u'chr.to.int$'),
   Identifier(u'duplicate$'),
   String(u'0'),
   Identifier(u'chr.to.int$'),
   Identifier(u'<'),
   Identifier(u'not'),
   Identifier(u'swap$'),
   String(u'9'),
   Identifier(u'chr.to.int$'),
   Identifier(u'>'),
   Identifier(u'not'),
   Identifier(u'and')]],
 [u'FUNCTION',
  [Identifier(u'extract.num')],
  [Identifier(u'duplicate$'),
   QuotedVar(u't'),
   Identifier(u':='),
   String(u''),
   QuotedVar(u's'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u't'), Identifier(u'empty$'), Identifier(u'not')]),
   FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':='), Identifier(u'duplicate$'), Identifier(u'is.num'), FunctionLiteral([Identifier(u's'), Identifier(u'swap$'), Identifier(u'*'), QuotedVar(u's'), Identifier(u':=')]), FunctionLiteral([Identifier(u'pop$'), String(u''), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]),
   Identifier(u'while$'),
   Identifier(u's'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'pop$'), Identifier(u's')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'convert.edition.superscript')],
  [Identifier(u'edition'),
   Identifier(u'extract.num'),
   String(u'l'),
   Identifier(u'change.case$'),
   QuotedVar(u's'),
   Identifier(u':='),
   Identifier(u's'),
   String(u'first'),
   Identifier(u'='),
   Identifier(u's'),
   String(u'1'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u's'),
   String(u'erste'),
   Identifier(u'='),
   Identifier(u'or'),
   FunctionLiteral([String(u'1'), QuotedVar(u't'), Identifier(u':=')]),
   FunctionLiteral([Identifier(u's'), String(u'second'), Identifier(u'='), Identifier(u's'), String(u'2'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'zweite'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'2'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'third'), Identifier(u'='), Identifier(u's'), String(u'3'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'dritte'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'3'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'fourth'), Identifier(u'='), Identifier(u's'), String(u'4'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'vierte'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'4'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'fifth'), Identifier(u'='), Identifier(u's'), String(u'5'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'fuenfte'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'5'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'sixth'), Identifier(u'='), Identifier(u's'), String(u'6'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'sechste'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'6'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'seventh'), Identifier(u'='), Identifier(u's'), String(u'7'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'siebte'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'siebente'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'7'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'eighth'), Identifier(u'='), Identifier(u's'), String(u'8'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'achte'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'8'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'nineth'), Identifier(u'='), Identifier(u's'), String(u'9'), Identifier(u'='), Identifier(u'or'), Identifier(u's'), String(u'neunte'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u'9'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u'is.num'), FunctionLiteral([Identifier(u's'), String(u''), Identifier(u'*'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u'edition'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u't')]],
 [u'FUNCTION',
  [Identifier(u'n.dashify')],
  [QuotedVar(u't'),
   Identifier(u':='),
   String(u''),
   FunctionLiteral([Identifier(u't'), Identifier(u'empty$'), Identifier(u'not')]),
   FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), String(u'-'), Identifier(u'='), FunctionLiteral([Identifier(u't'), Integer(1), Integer(2), Identifier(u'substring$'), String(u'--'), Identifier(u'='), Identifier(u'not'), FunctionLiteral([String(u'--'), Identifier(u'*'), Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), String(u'-'), Identifier(u'=')]), FunctionLiteral([String(u'-'), Identifier(u'*'), Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'while$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u'*'), Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'output.bibitem.fst')],
  [Identifier(u'newline$'),
   String(u'\\bibitem[{'),
   Identifier(u'write$'),
   Identifier(u'shortauthor'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'juraauthor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'archive'), Identifier(u'empty$'), FunctionLiteral([String(u'empty'), Identifier(u'write$')]), FunctionLiteral([Identifier(u'archive'), Identifier(u'write$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'organization'), Identifier(u'write$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'label'), Identifier(u'write$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'label'), Identifier(u'write$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'juraauthor'), Identifier(u'write$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'shortauthor'), Identifier(u'write$')]),
   Identifier(u'if$'),
   String(u'}%'),
   Identifier(u'write$'),
   Identifier(u'sortkey'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'newline$'), String(u'% SORTKEY: ['), Identifier(u'sortkey'), Identifier(u'*'), String(u']'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'newline$'),
   Identifier(u'shorttitle'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'juratitle'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'journal'), Identifier(u'empty$'), FunctionLiteral([String(u'         {}%'), Identifier(u'write$')]), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'         {'), Identifier(u'journal'), Identifier(u'*'), String(u'}%'), Identifier(u'*'), Identifier(u'write$')]), FunctionLiteral([String(u'         {'), Identifier(u'journal'), Identifier(u'*'), String(u'\\jbsy {'), Identifier(u'*'), Identifier(u'year'), Identifier(u'*'), String(u'}}%'), Identifier(u'*'), Identifier(u'write$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'         {'), Identifier(u'journal'), Identifier(u'*'), String(u'}%'), Identifier(u'*'), Identifier(u'write$')]), FunctionLiteral([String(u'         {'), Identifier(u'journal'), Identifier(u'*'), String(u' '), Identifier(u'*'), Identifier(u'volume'), Identifier(u'*'), String(u' '), Identifier(u'*'), String(u' \\peryearformat {'), Identifier(u'year'), Identifier(u'*'), String(u'}}%'), Identifier(u'*'), Identifier(u'*'), Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([String(u'         {'), Identifier(u'juratitle'), Identifier(u'*'), String(u'}%'), Identifier(u'*'), Identifier(u'write$')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'         {'), Identifier(u'shorttitle'), Identifier(u'*'), String(u'}%'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'newline$'),
   Identifier(u'repeat-authors'),
   FunctionLiteral([String(u'         {{1}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'         {{0}'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'howcited'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'howcited'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'type$'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'type$'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'type$'), String(u'book'), Identifier(u'='), Identifier(u'dissyear'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'{'), Identifier(u'dissyear'), Identifier(u'*'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), Identifier(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$'), String(u'}'), Identifier(u'write$')]), FunctionLiteral([String(u'{}'), Identifier(u'write$')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'{'), Identifier(u'year'), Identifier(u'*'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$'), String(u'}'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'edition'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'convert.edition.superscript'), Identifier(u'extract.num'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'ssedition'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'ssedition'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'language'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'language'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'pages'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}%'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'write$'), Identifier(u'pages'), Identifier(u'n.dashify'), Identifier(u'write$'), String(u'}%'), Identifier(u'write$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'output.bibitem.snd')],
  [Identifier(u'newline$'),
   Identifier(u'publisher'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'          {'), Identifier(u'write$')]), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'year'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'address'), Identifier(u'write$')]), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'address'), Identifier(u'write$'), String(u'\\bibbdsep {} '), Identifier(u'write$'), Identifier(u'year'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'publisher'), Identifier(u'write$')]), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'publisher'), Identifier(u'write$'), String(u'\\bibbdsep {} '), Identifier(u'write$'), Identifier(u'year'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'address'), Identifier(u'write$'), String(u'\\bpubaddr {} '), Identifier(u'write$'), Identifier(u'publisher'), Identifier(u'write$')]), FunctionLiteral([String(u'          {'), Identifier(u'write$'), Identifier(u'address'), Identifier(u'write$'), String(u'\\bpubaddr {} '), Identifier(u'write$'), Identifier(u'publisher'), Identifier(u'write$'), String(u'\\bibbdsep {} '), Identifier(u'write$'), Identifier(u'year'), Identifier(u'write$'), Identifier(u'extra.label'), String(u''), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\el {'), Identifier(u'write$'), Identifier(u'extra.label'), Identifier(u'write$'), String(u'}'), Identifier(u'write$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   String(u'}}%'),
   Identifier(u'write$'),
   Identifier(u'newline$'),
   String(u'         {'),
   Identifier(u'write$'),
   Identifier(u'title'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}%'), Identifier(u'write$'), Identifier(u'newline$')]),
   FunctionLiteral([String(u'{'), Identifier(u'title'), Identifier(u'*'), Identifier(u'type$'), String(u'archival'), Identifier(u'='), FunctionLiteral([Identifier(u'shortarchive'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u', In: '), Identifier(u'shortarchive'), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([Identifier(u'archive'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u', In: '), Identifier(u'archive'), Identifier(u'*'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'shortsubarchive'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'shortsubarchive'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'sig1'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'sig1'), Identifier(u'*'), Identifier(u'*'), Identifier(u'sig2'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig2'), Identifier(u'*'), Identifier(u'*'), Identifier(u'sig3'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig3'), Identifier(u'*'), Identifier(u'*'), Identifier(u'sig4'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig4'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'pages'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u' \\jbArchPages {'), Identifier(u'pages'), Identifier(u'n.dashify'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), QuotedVar(u'skip$'), Identifier(u'if$'), String(u'}%'), Identifier(u'*'), Identifier(u'write$'), Identifier(u'newline$')]),
   Identifier(u'if$'),
   Identifier(u'gender'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'          {}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'          {'), Identifier(u'gender'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'oyear'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'write$')]),
   FunctionLiteral([String(u'{'), Identifier(u'oyear'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u'{4}'), Identifier(u'write$')]), FunctionLiteral([String(u'{3}'), Identifier(u'write$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u'{2}'), Identifier(u'write$')]), FunctionLiteral([String(u'{1}'), Identifier(u'write$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   String(u'{}{}{}{}{}}%'),
   Identifier(u'write$'),
   Identifier(u'newline$'),
   String(u'        ]{'),
   Identifier(u'write$'),
   Identifier(u'cite$'),
   Identifier(u'write$'),
   String(u'}'),
   Identifier(u'write$'),
   Identifier(u'url'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'newline$'), String(u' \\jburldef {'), Identifier(u'write$'), Identifier(u'cite$'), Identifier(u'write$'), String(u'}{'), Identifier(u'write$'), Identifier(u'url'), Identifier(u'write$'), String(u'}%'), Identifier(u'write$')]),
   Identifier(u'if$'),
   Identifier(u'newline$'),
   String(u' \\jbbibargs {'),
   Identifier(u'write$'),
   String(u''),
   Identifier(u'before.all'),
   QuotedVar(u'output.state'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'output.bibitem')],
  [Identifier(u'output.bibitem.fst'), Identifier(u'output.bibitem.snd')]],
 [u'FUNCTION',
  [Identifier(u'format.note')],
  [Identifier(u'note'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'output.state'), Identifier(u'before.all'), Identifier(u'='), FunctionLiteral([String(u' \\jbnote {} {'), Identifier(u'*'), Identifier(u'note'), Identifier(u'*'), String(u'} '), Identifier(u'*')]), FunctionLiteral([String(u' \\jbnote {1} {'), Identifier(u'*'), Identifier(u'note'), Identifier(u'*'), String(u'} '), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.endnote')],
  [Identifier(u'note'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u'  \\jbendnote {'), Identifier(u'note'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.juradiss.book')],
  [Identifier(u'dissyear'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'type'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'school'), Identifier(u'empty$'), FunctionLiteral([String(u'Dissyear but no school in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u' (\\alsothesisname {} \\jurthesisname'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'year'), Identifier(u'missing$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'\\bibbdsep {} '), Identifier(u'dissyear'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$'), String(u')'), Identifier(u'*')]), FunctionLiteral([String(u' (\\alsothesisname {} \\jurthesisname, '), Identifier(u'school'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'year'), Identifier(u'missing$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'\\bibbdsep {} '), Identifier(u'dissyear'), Identifier(u'*'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$'), String(u')'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'school'), Identifier(u'empty$'), FunctionLiteral([String(u'Dissyear but no school in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u' (\\alsothesisname {} '), Identifier(u'type'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'year'), Identifier(u'missing$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'\\bibbdsep {} '), Identifier(u'dissyear'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$'), String(u')'), Identifier(u'*')]), FunctionLiteral([String(u' (\\alsothesisname {} '), Identifier(u'type'), Identifier(u'*'), String(u', '), Identifier(u'school'), Identifier(u'*'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'year'), Identifier(u'missing$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'\\bibbdsep {} '), Identifier(u'dissyear'), Identifier(u'*'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$'), String(u')'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.thesis')],
  [Identifier(u'year'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'school'), Identifier(u'empty$'), FunctionLiteral([String(u'No universtiy in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), FunctionLiteral([String(u"There's a university, but no year in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), Identifier(u'if$'), String(u'')]),
   FunctionLiteral([Identifier(u'type'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'school'), Identifier(u'empty$'), FunctionLiteral([String(u'No university in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'type$'), String(u'mastersthesis'), Identifier(u'='), FunctionLiteral([String(u'\\apyformat {\\mastersthesisname'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'jurthesis'), Identifier(u'='), FunctionLiteral([String(u'\\apyformat {\\jurthesisname'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u'\\apyformat {\\phdthesisname'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'type$'), String(u'mastersthesis'), Identifier(u'='), FunctionLiteral([String(u'\\mastersthesisname, \\apyformat {'), Identifier(u'school'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'jurthesis'), Identifier(u'='), FunctionLiteral([String(u'\\jurthesisname, \\apyformat {'), Identifier(u'school'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u'\\phdthesisname, \\apyformat {'), Identifier(u'school'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'school'), Identifier(u'empty$'), FunctionLiteral([String(u'No university in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'type'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'address'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'type'), String(u' \\apyformat {'), Identifier(u'*'), Identifier(u'school'), Identifier(u'*'), Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'address'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\bibbdsep {} '), Identifier(u'year'), Identifier(u'*'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'set.comma.pages.check')],
  [Identifier(u'year'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'pages'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'url'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u', '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u', '), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'set.period.dash')],
  [Identifier(u'output.state'),
   Identifier(u'before.all'),
   Identifier(u'='),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'period.dash'), QuotedVar(u'output.state'), Identifier(u':=')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'set.period.dash.check')],
  [Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   QuotedVar(u'set.period.dash'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'new.sentence')],
  [Identifier(u'output.state'),
   Identifier(u'before.all'),
   Identifier(u'='),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'after.sentence'), QuotedVar(u'output.state'), Identifier(u':=')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'part.of.sentence')],
  [Identifier(u'output.state'),
   Identifier(u'before.all'),
   Identifier(u'='),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'mid.sentence'), QuotedVar(u'output.state'), Identifier(u':=')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'new.sentence.checka')],
  [Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   QuotedVar(u'new.sentence'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'field.or.null')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'get.final.nonrightbrace.char')],
  [FunctionLiteral([Identifier(u'duplicate$'), Integer(-1), Integer(1), Identifier(u'substring$'), Identifier(u'duplicate$'), String(u'}'), Identifier(u'=')]),
   FunctionLiteral([Identifier(u'pop$'), Integer(-2), Identifier(u'global.max$'), Identifier(u'substring$')]),
   Identifier(u'while$'),
   Identifier(u'swap$'),
   Identifier(u'pop$')]],
 [u'FUNCTION',
  [Identifier(u'check.punct.instead.of.add.period')],
  [Identifier(u'duplicate$'),
   Identifier(u'get.final.nonrightbrace.char'),
   Identifier(u'duplicate$'),
   String(u'.'),
   Identifier(u'='),
   Identifier(u'swap$'),
   Identifier(u'duplicate$'),
   String(u'!'),
   Identifier(u'='),
   Identifier(u'swap$'),
   String(u'?'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'or'),
   FunctionLiteral([String(u'} '), Identifier(u'*')]),
   FunctionLiteral([String(u'}\\bibatsep\\ '), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'check.punct.instead.of.add.period.art')],
  [Identifier(u'duplicate$'),
   Identifier(u'get.final.nonrightbrace.char'),
   Identifier(u'duplicate$'),
   String(u'.'),
   Identifier(u'='),
   Identifier(u'swap$'),
   Identifier(u'duplicate$'),
   String(u'!'),
   Identifier(u'='),
   Identifier(u'swap$'),
   String(u'?'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'or'),
   FunctionLiteral([String(u'} '), Identifier(u'*')]),
   FunctionLiteral([Identifier(u'pages'), Identifier(u'empty$'), Identifier(u'note'), Identifier(u'empty$'), Identifier(u'url'), Identifier(u'empty$'), Identifier(u'and'), Identifier(u'and'), FunctionLiteral([String(u'} '), Identifier(u'*')]), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'pages'), Identifier(u'empty$'), FunctionLiteral([String(u'}\\ajtsep\\ '), Identifier(u'*')]), FunctionLiteral([Identifier(u'crossref'), Identifier(u'missing$'), FunctionLiteral([Identifier(u'month'), Identifier(u'empty$'), FunctionLiteral([String(u'}\\ajtsep\\ '), Identifier(u'*')]), FunctionLiteral([String(u'}\\ajtsep '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'}\\ajtsep '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([String(u'}\\ajtsep\\ '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'emphasize')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([String(u'\\bibtfont {'), Identifier(u'swap$'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'journaltitlemarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([String(u'\\bibJTsep \\bibjtfont {'), Identifier(u'swap$'), Identifier(u'check.punct.instead.of.add.period.art'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'incollbooktitlemarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([String(u'\\bibbtfont {'), Identifier(u'swap$'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'INTEGERS',
  [Identifier(u'nameptr'), Identifier(u'namesleft'), Identifier(u'numnames')]],
 [u'FUNCTION',
  [Identifier(u'lastnamemarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([String(u'\\bibnf {'), Identifier(u'swap$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'editorlastnamemarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([String(u'\\biblenf {'), Identifier(u'swap$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u'\\bibenf {'), Identifier(u'swap$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'othermarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u' {}')]),
   FunctionLiteral([String(u' {'), Identifier(u'swap$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'article.in.journal')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'missing$'), FunctionLiteral([Identifier(u'title'), Identifier(u'missing$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'journaltitlemarkup'), String(u''), Identifier(u'swap$'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'journaltitlemarkup'), String(u''), Identifier(u'swap$'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.names')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u's'), Identifier(u'nameptr'), String(u'{ll}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u't'), Identifier(u'lastnamemarkup'), QuotedVar(u't'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{ff}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'u'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{f.}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'v'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{vv}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'w'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{jj}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'x'), Identifier(u':='), Identifier(u't'), Identifier(u'u'), Identifier(u'*'), Identifier(u'v'), Identifier(u'*'), Identifier(u'w'), Identifier(u'*'), Identifier(u'x'), Identifier(u'*'), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'>'), FunctionLiteral([String(u''), Identifier(u'*')]), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'<'), FunctionLiteral([String(u'\\Bibbtasep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([String(u'\\Bibbfsasep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u't'), String(u'\\bibnf {others} {} {} {} {}'), Identifier(u'='), Identifier(u't'), String(u'\\bibnf {others} {} {} {} {} \\edfont {\\editorsname}'), Identifier(u'='), Identifier(u'or'), Identifier(u'numnames'), Integer(3), Identifier(u'>'), Identifier(u'or'), FunctionLiteral([String(u'\\bibIMfont {\\Bibetal}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'<'), FunctionLiteral([String(u'\\Bibbtasep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([String(u'\\Bibbstasep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'format.editor.names')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u's'), Identifier(u'nameptr'), String(u'{ll}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u't'), Identifier(u'editorlastnamemarkup'), QuotedVar(u't'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{ff}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'u'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{f.}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'v'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{vv}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'w'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{jj}'), Identifier(u'format.name$'), Identifier(u'othermarkup'), QuotedVar(u'x'), Identifier(u':='), Identifier(u't'), Identifier(u'u'), Identifier(u'*'), Identifier(u'v'), Identifier(u'*'), Identifier(u'w'), Identifier(u'*'), Identifier(u'x'), Identifier(u'*'), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'>'), FunctionLiteral([String(u''), Identifier(u'*')]), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'<'), FunctionLiteral([String(u'\\Bibbtesep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([String(u'\\Bibbfsesep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u't'), String(u'\\bibenf {others} {} {} {} {}'), Identifier(u'='), Identifier(u't'), String(u'\\biblenf {others} {} {} {} {}'), Identifier(u'='), Identifier(u'or'), Identifier(u't'), String(u'\\bibenf {others} {} {} {} {} \\edfont {\\editorsname}'), Identifier(u'='), Identifier(u'or'), Identifier(u't'), String(u'\\biblenf {others} {} {} {} {} \\edfont {\\editorsname}'), Identifier(u'='), Identifier(u'or'), Identifier(u'numnames'), Integer(3), Identifier(u'>'), Identifier(u'or'), FunctionLiteral([String(u'\\bibIMfont {\\Bibetal}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'numnames'), Integer(3), Identifier(u'<'), FunctionLiteral([String(u'\\Bibbtesep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([String(u'\\Bibbstesep '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'format.name.sig')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u's'), Identifier(u'nameptr'), String(u'{ff}{ vv}{ ll}{ jj}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u''), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([Identifier(u't'), String(u'others'), Identifier(u'='), FunctionLiteral([String(u' et al.'), Identifier(u'*')]), FunctionLiteral([String(u''), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'indexmarkup')],
  [Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'pop$'), String(u'{}')]),
   FunctionLiteral([String(u'{'), Identifier(u'swap$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.names.for.index')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u's'), Identifier(u'nameptr'), String(u'{ll}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u't'), Identifier(u'indexmarkup'), QuotedVar(u't'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{ff}'), Identifier(u'format.name$'), Identifier(u'indexmarkup'), QuotedVar(u'u'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{f.}'), Identifier(u'format.name$'), Identifier(u'indexmarkup'), QuotedVar(u'v'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{vv}'), Identifier(u'format.name$'), Identifier(u'indexmarkup'), QuotedVar(u'w'), Identifier(u':='), Identifier(u's'), Identifier(u'nameptr'), String(u'{jj}'), Identifier(u'format.name$'), Identifier(u'indexmarkup'), QuotedVar(u'x'), Identifier(u':='), Identifier(u't'), Identifier(u'u'), Identifier(u'*'), Identifier(u'v'), Identifier(u'*'), Identifier(u'w'), Identifier(u'*'), Identifier(u'x'), Identifier(u'*'), QuotedVar(u't'), Identifier(u':='), Identifier(u't'), String(u'{others}{}{}{}{}'), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'; '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([Identifier(u't'), String(u'others'), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([String(u'; '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'format.authors')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'format.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.founders')],
  [Identifier(u'founder'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u' in: '), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'founder'), Identifier(u'format.names'), String(u'\\foundername'), Identifier(u'*'), Identifier(u'*'), Identifier(u'editor'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([String(u'\\afterfoundersep {}'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.editors')],
  [Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'format.editor.names'), Identifier(u'editortype'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'num.names$'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'\\fsted {\\editorsname}'), Identifier(u'*')]), FunctionLiteral([String(u'\\fsted {\\editorname}'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'\\fsted {('), Identifier(u'editortype'), Identifier(u'*'), String(u')}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'founder'), Identifier(u'empty$'), FunctionLiteral([String(u'\\bibfnfont {;} '), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'commented'), Identifier(u'='), FunctionLiteral([String(u'\\afterfoundersep {}'), Identifier(u'*')]), FunctionLiteral([String(u'\\bibfnfont {;} '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'editor'), Identifier(u'format.editor.names'), Identifier(u'*'), Identifier(u'editortype'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'num.names$'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u' \\edfont {\\editorsname}'), Identifier(u'*')]), FunctionLiteral([String(u' \\edfont {\\editorname}'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u' \\edfont {('), Identifier(u'editortype'), Identifier(u'*'), String(u')}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.snd.editors')],
  [Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u''), Identifier(u'*')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editortype'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'num.names$'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'\\snded {\\sndeditorsname}'), Identifier(u'*')]), FunctionLiteral([String(u'\\snded {\\sndeditorname}'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'\\snded {('), Identifier(u'editortype'), Identifier(u'*'), String(u')}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), QuotedVar(u'skip$'), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.howcited')],
  [String(u'} {\\bibhowcited}'),
   Identifier(u'format.endnote'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'fin.entry.endnote')],
  [String(u' \\jbdoitem {'),
   Identifier(u'*'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'author'), Identifier(u'format.names.for.index'), Identifier(u'*')]),
   Identifier(u'if$'),
   String(u'} {'),
   Identifier(u'editor'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'format.names.for.index'), Identifier(u'*')]),
   Identifier(u'if$'),
   String(u'} {'),
   Identifier(u'*'),
   Identifier(u'organization'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'{'), Identifier(u'organization'), Identifier(u'*'), String(u'}{}{}{}{}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   String(u'}'),
   Identifier(u'*'),
   Identifier(u'*'),
   Identifier(u'write$'),
   Identifier(u'annote'),
   Identifier(u'missing$'),
   FunctionLiteral([String(u' \\bibAnnoteFile {'), Identifier(u'cite$'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$'), Identifier(u'newline$')]),
   FunctionLiteral([String(u' \\bibAnnote {'), Identifier(u'annote'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'write$'), Identifier(u'newline$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'count.authors.or.editors')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([String(u''), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u''), Identifier(u'*')]), FunctionLiteral([String(u's'), Identifier(u'*')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'set.after.author.sep')],
  [Identifier(u'author'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'missing$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'missing$'), FunctionLiteral([Identifier(u'archive'), Identifier(u'missing$'), FunctionLiteral([String(u'} {empty} {} {')]), FunctionLiteral([String(u'} {'), Identifier(u'archive'), Identifier(u'format.name.sig'), Identifier(u'*'), String(u'} {} {'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'} {'), Identifier(u'organization'), String(u'} {org} {'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'} {'), Identifier(u'editor'), Identifier(u'format.name.sig'), Identifier(u'*'), String(u'} {ed'), Identifier(u'editor'), Identifier(u'count.authors.or.editors'), String(u'} {'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'} {'), Identifier(u'author'), Identifier(u'format.name.sig'), Identifier(u'*'), String(u'} {au'), Identifier(u'author'), Identifier(u'count.authors.or.editors'), String(u'} {'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'format.snd.editors')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$'),
   String(u''),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.names.info')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u's'), Identifier(u'nameptr'), String(u'{ff }{vv }{ll}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([Identifier(u'namesleft'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u' '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), FunctionLiteral([Identifier(u't'), String(u'others'), Identifier(u'='), FunctionLiteral([String(u' et al.'), Identifier(u'*')]), FunctionLiteral([String(u' '), Identifier(u'*'), Identifier(u't'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u't'), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'format.howcited.comment')],
  [Identifier(u'edition'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'} {\\bibcommenthowcited}'), Identifier(u'format.endnote'), Identifier(u'*')]),
   FunctionLiteral([String(u'} {\\bibcommenthowcited}'), Identifier(u'format.endnote'), Identifier(u'*'), Identifier(u'*'), Identifier(u'author'), Identifier(u'empty$'), Identifier(u'editor'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u' \\jbauthorinfo {'), Identifier(u'editor'), Identifier(u'format.names.info'), String(u' '), Identifier(u'title'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*'), String(u'}{'), Identifier(u'cite$'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), Identifier(u'shortauthor'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u' \\jbauthorinfo {'), Identifier(u'shortauthor'), Identifier(u'format.names.info'), String(u' '), Identifier(u'title'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*'), String(u'}{'), Identifier(u'cite$'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([String(u' \\jbauthorinfo {'), Identifier(u'author'), Identifier(u'format.names.info'), String(u' '), Identifier(u'title'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*'), String(u'}{'), Identifier(u'cite$'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.howcited.artperiod')],
  [String(u'} {\\bibartperiodhowcited}'),
   Identifier(u'format.endnote'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.proceed.organization')],
  [Identifier(u'organization'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'organization'), String(u' \\organizationname {}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.titleaddon')],
  [Identifier(u'title'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'titleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'titleaddon'), String(u'\\bibatsep\\ '), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.title')],
  [Identifier(u'title'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u'\\bibtfont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.artperiodincoll.title')],
  [Identifier(u'title'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.volumetitle')],
  [Identifier(u'volumetitle'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u"There's a volumetitle but no volume in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'volumetitle'), String(u', '), Identifier(u'*')]), FunctionLiteral([Identifier(u'volumetitle'), String(u', '), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'add.extra.label')],
  [Identifier(u'extra.label'),
   String(u''),
   Identifier(u'='),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\bibel {'), Identifier(u'extra.label'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.date')],
  [Identifier(u'year'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'month'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([String(u"There's a month but no year in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'month')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'month'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'edition'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\jbssedbd {'), Identifier(u'convert.edition.superscript'), Identifier(u'extract.num'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'year'), Identifier(u'add.extra.label')]), FunctionLiteral([Identifier(u'month'), String(u' '), Identifier(u'*'), Identifier(u'edition'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\jbssedbd {'), Identifier(u'convert.edition.superscript'), Identifier(u'extract.num'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'year'), Identifier(u'*'), Identifier(u'add.extra.label')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.update')],
  [Identifier(u'updated'),
   Identifier(u'missing$'),
   Identifier(u'not'),
   FunctionLiteral([String(u'\\updatesep {} \\updatename {} '), Identifier(u'*'), Identifier(u'updated'), Identifier(u'*')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'oaddress.opublisher.oyear.format')],
  [Identifier(u'type$'),
   String(u'book'),
   Identifier(u'='),
   Identifier(u'type$'),
   String(u'inbook'),
   Identifier(u'='),
   Identifier(u'type$'),
   String(u'incollection'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'or'),
   FunctionLiteral([Identifier(u'oyear'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'opublisher'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'oaddress'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'oaddress'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'oaddress'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'opublisher'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([Identifier(u'oaddress'), String(u'\\bpubaddr {} '), Identifier(u'*'), Identifier(u'opublisher'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'oyear without year in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), QuotedVar(u'skip$'), Identifier(u'if$'), Identifier(u'opublisher'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'oaddress'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'oyear'), Identifier(u'*'), String(u'\\osep {} \\reprintname {}, '), Identifier(u'*')]), FunctionLiteral([Identifier(u'oaddress'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'oyear'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'oaddress'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'opublisher'), Identifier(u'*'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'oyear'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([Identifier(u'oaddress'), String(u'\\bpubaddr {} '), Identifier(u'*'), Identifier(u'opublisher'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'oyear'), String(u'\\osep {} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'make.translators')],
  [Identifier(u'before.all'),
   QuotedVar(u'output.state'),
   Identifier(u':='),
   Identifier(u'translator'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'flanguage'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([String(u'\\translator {}{'), Identifier(u'flanguage'), String(u'l'), Identifier(u'change.case$'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'type$'), String(u'incollection'), Identifier(u'='), Identifier(u'not'), Identifier(u'type$'), String(u'article'), Identifier(u'='), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'incollection'), Identifier(u'='), FunctionLiteral([Identifier(u'booktitle'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'type$'), String(u'article'), Identifier(u'='), FunctionLiteral([String(u'{1}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'\\translator {'), Identifier(u'translator'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'flanguage'), Identifier(u'empty$'), FunctionLiteral([String(u'{}'), Identifier(u'*')]), FunctionLiteral([String(u'{'), Identifier(u'*'), Identifier(u'flanguage'), String(u'l'), Identifier(u'change.case$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'type$'), String(u'incollection'), Identifier(u'='), Identifier(u'not'), Identifier(u'type$'), String(u'article'), Identifier(u'='), Identifier(u'not'), Identifier(u'and'), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'incollection'), Identifier(u'='), FunctionLiteral([Identifier(u'booktitle'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'type$'), String(u'article'), Identifier(u'='), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'before.all'),
   QuotedVar(u'output.state'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'checked.inst')],
  [Identifier(u'institution'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u' \\apyformat {'), Identifier(u'*'), Identifier(u'oaddress.opublisher.oyear.format')]),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.address.publisher.year')],
  [Identifier(u'publisher'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'Neither address nor year in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([String(u'No address in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'institution'), Identifier(u'empty$'), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'oaddress.opublisher.oyear.format'), Identifier(u'format.date'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'institution'), Identifier(u'*'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'checked.inst'), Identifier(u'address'), String(u'}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'checked.inst'), Identifier(u'address'), String(u'\\bibbdsep {} '), Identifier(u'format.date'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u"There's only a publisher (no address, no year) in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'publisher')]), FunctionLiteral([Identifier(u'checked.inst'), Identifier(u'publisher'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'checked.inst'), Identifier(u'address'), Identifier(u'*'), String(u'\\bpubaddr {} '), Identifier(u'publisher'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([Identifier(u'checked.inst'), Identifier(u'address'), Identifier(u'*'), String(u'\\bpubaddr {} '), Identifier(u'publisher'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.howpublished.address.year')],
  [Identifier(u'howpublished'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'Neither address nor year in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([String(u'No address in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'format.date')]), Identifier(u'if$')]), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'oaddress.opublisher.oyear.format'), Identifier(u'address'), Identifier(u'*'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u"There's only a howpublished (no address, no year) in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), Identifier(u'howpublished')]), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'oaddress.opublisher.oyear.format'), Identifier(u'howpublished'), Identifier(u'*'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'oaddress.opublisher.oyear.format'), Identifier(u'address'), Identifier(u'*'), String(u'\\bpubaddr {} '), Identifier(u'*'), Identifier(u'howpublished'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([String(u' \\apyformat {'), Identifier(u'oaddress.opublisher.oyear.format'), Identifier(u'address'), Identifier(u'*'), String(u'\\bpubaddr {} '), Identifier(u'*'), Identifier(u'howpublished'), Identifier(u'*'), String(u'\\bibbdsep {} '), Identifier(u'*'), Identifier(u'format.date'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'tie.or.space.connect')],
  [Identifier(u'duplicate$'),
   Identifier(u'text.length$'),
   Integer(4),
   Identifier(u'<'),
   FunctionLiteral([String(u'~')]),
   FunctionLiteral([String(u' ')]),
   Identifier(u'if$'),
   Identifier(u'swap$'),
   Identifier(u'*'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'bibvol.tie.or.space.connect')],
  [Identifier(u'duplicate$'),
   Identifier(u'text.length$'),
   Integer(4),
   Identifier(u'<'),
   FunctionLiteral([String(u'~')]),
   FunctionLiteral([String(u'{} ')]),
   Identifier(u'if$'),
   Identifier(u'swap$'),
   Identifier(u'*'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.btitle')],
  [Identifier(u'title'),
   Identifier(u'emphasize'),
   Identifier(u'format.titleaddon'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.btitle.vol')],
  [Identifier(u'number'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'format.titleaddon'), Identifier(u'*')]), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'format.titleaddon'), Identifier(u'*'), String(u' \\volumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'format.titleaddon'), Identifier(u'*')]), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'format.titleaddon'), Identifier(u'*'), String(u'\\volumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*'), Identifier(u'*'), Identifier(u'series'), String(u'\\bibatsep\\ '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'format.titleaddon'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.btitle.vol.inbook')],
  [Identifier(u'number'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*')]), FunctionLiteral([String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*'), String(u' \\volumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*')]), FunctionLiteral([Identifier(u'series'), Identifier(u'emphasize'), String(u'\\volumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*'), Identifier(u'*'), String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'\\bibapifont {'), Identifier(u'title'), Identifier(u'check.punct.instead.of.add.period'), Identifier(u'*'), Identifier(u'format.titleaddon'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.url')],
  [Identifier(u'url'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), Identifier(u'title'), Identifier(u'empty$'), Identifier(u'and'), QuotedVar(u'skip$'), FunctionLiteral([String(u' '), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'urldate'), Identifier(u'empty$'), FunctionLiteral([String(u'\\jburluse {'), Identifier(u'cite$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u'\\jburluse {'), Identifier(u'cite$'), Identifier(u'*'), String(u'}\\bibbudcsep {}\\urldatecomment '), Identifier(u'*'), Identifier(u'urldate'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.naked.url')],
  [Identifier(u'url'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'urldate'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'title'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\jburluse {'), Identifier(u'cite$'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([Identifier(u'title'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'title'), Identifier(u'emphasize'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\jburluse {'), Identifier(u'cite$'), Identifier(u'*'), String(u'}\\bibbudcsep {}\\urldatecomment '), Identifier(u'*'), Identifier(u'urldate'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.series.number')],
  [Identifier(u'volume'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'number'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([String(u' \\numberandseries {}{'), Identifier(u'series'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u' \\numberandseries {'), Identifier(u'number'), Identifier(u'*'), String(u'}{}'), Identifier(u'*'), String(u"There's a number but no series in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), FunctionLiteral([String(u' \\numberandseries {'), Identifier(u'number'), Identifier(u'*'), String(u'}{'), Identifier(u'*'), Identifier(u'series'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'type$'), String(u'proceedings'), Identifier(u'='), FunctionLiteral([String(u' \\numberandseries {}{'), Identifier(u'series'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), FunctionLiteral([String(u'')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION', [Identifier(u'first.ed')], [String(u'\\firstedname')]],
 [u'FUNCTION', [Identifier(u'second.ed')], [String(u'\\secondedname')]],
 [u'FUNCTION', [Identifier(u'third.ed')], [String(u'\\thirdedname')]],
 [u'FUNCTION', [Identifier(u'fourth.ed')], [String(u'\\fourthedname')]],
 [u'FUNCTION', [Identifier(u'fifth.ed')], [String(u'\\fifthedname')]],
 [u'FUNCTION', [Identifier(u'th.ed')], [String(u'\\thedname')]],
 [u'FUNCTION',
  [Identifier(u'convert.edition')],
  [Identifier(u'edition'),
   Identifier(u'extract.num'),
   String(u'l'),
   Identifier(u'change.case$'),
   QuotedVar(u's'),
   Identifier(u':='),
   Identifier(u's'),
   String(u'first'),
   Identifier(u'='),
   Identifier(u's'),
   String(u'1'),
   Identifier(u'='),
   Identifier(u'or'),
   FunctionLiteral([Identifier(u'first.ed'), QuotedVar(u't'), Identifier(u':=')]),
   FunctionLiteral([Identifier(u's'), String(u'second'), Identifier(u'='), Identifier(u's'), String(u'2'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'second.ed'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'third'), Identifier(u'='), Identifier(u's'), String(u'3'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'third.ed'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'fourth'), Identifier(u'='), Identifier(u's'), String(u'4'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'fourth.ed'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), String(u'fifth'), Identifier(u'='), Identifier(u's'), String(u'5'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'fifth.ed'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u's'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u'is.num'), FunctionLiteral([Identifier(u's'), Identifier(u'th.ed'), Identifier(u'*'), QuotedVar(u't'), Identifier(u':=')]), FunctionLiteral([Identifier(u'edition'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u't')]],
 [u'FUNCTION',
  [Identifier(u'format.edition')],
  [Identifier(u'edition'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u'\\jbedition {'), Identifier(u'*'), Identifier(u'convert.edition'), String(u'~\\editionname {}\\jbaensep} '), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.isbn.issn')],
  [Identifier(u'isbn'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'issn'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([String(u'\\jbissn {'), Identifier(u'issn'), Identifier(u'n.dashify'), Identifier(u'*'), String(u'}'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'\\jbisbn {'), Identifier(u'isbn'), Identifier(u'n.dashify'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'INTEGERS', [Identifier(u'multiresult')]],
 [u'FUNCTION',
  [Identifier(u'multi.page.check')],
  [QuotedVar(u't'),
   Identifier(u':='),
   Integer(0),
   QuotedVar(u'multiresult'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'multiresult'), Identifier(u'not'), Identifier(u't'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'and')]),
   FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u'duplicate$'), String(u'-'), Identifier(u'='), Identifier(u'swap$'), Identifier(u'duplicate$'), String(u','), Identifier(u'='), Identifier(u'swap$'), String(u'+'), Identifier(u'='), Identifier(u'or'), Identifier(u'or'), FunctionLiteral([Integer(1), QuotedVar(u'multiresult'), Identifier(u':=')]), FunctionLiteral([Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]),
   Identifier(u'while$'),
   Identifier(u'multiresult')]],
 [u'FUNCTION',
  [Identifier(u'format.pages')],
  [Identifier(u'pages'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u' \\jbPages{'), Identifier(u'pages'), Identifier(u'n.dashify'), Identifier(u'*'), String(u'}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'multi.pagerange.check')],
  [QuotedVar(u't'),
   Identifier(u':='),
   Integer(0),
   QuotedVar(u'multiresult'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'multiresult'), Identifier(u'not'), Identifier(u't'), Identifier(u'empty$'), Identifier(u'not'), Identifier(u'and')]),
   FunctionLiteral([Identifier(u't'), Integer(1), Integer(1), Identifier(u'substring$'), Identifier(u'duplicate$'), String(u'-'), Identifier(u'='), Identifier(u'swap$'), Identifier(u'duplicate$'), String(u'b'), Identifier(u'='), Identifier(u'swap$'), String(u'/'), Identifier(u'='), Identifier(u'or'), Identifier(u'or'), FunctionLiteral([Integer(1), QuotedVar(u'multiresult'), Identifier(u':=')]), FunctionLiteral([Identifier(u't'), Integer(2), Identifier(u'global.max$'), Identifier(u'substring$'), QuotedVar(u't'), Identifier(u':=')]), Identifier(u'if$')]),
   Identifier(u'while$'),
   Identifier(u'multiresult')]],
 [u'FUNCTION',
  [Identifier(u'check.missing.pages')],
  [Identifier(u'pages'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'Empty pages in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]),
   FunctionLiteral([Identifier(u'pages'), Identifier(u'multi.pagerange.check'), FunctionLiteral([String(u''), Identifier(u'*')]), FunctionLiteral([Identifier(u'type$'), String(u'article'), Identifier(u'='), Identifier(u'type$'), String(u'periodical'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([String(u"There's only a starting page, no pagerange in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.pages.book')],
  [Identifier(u'pages'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u' \\jbpages {'), Identifier(u'pages'), String(u' \\bibtotalpagesname}'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.totalpages')],
  [Identifier(u'totalpages'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u', '), Identifier(u'totalpages'), String(u'~\\bibtotalpagesname'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.vol.year.num.pages')],
  [Identifier(u'volume'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u' \\artvolumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u"There's a volume but no year in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), QuotedVar(u'skip$'), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'month'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\ '), Identifier(u'month'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u' \\artyearformat {'), Identifier(u'year'), Identifier(u'*'), Identifier(u'add.extra.label'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'number'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\artnumberformat {'), Identifier(u'number'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'pages'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'duplicate$'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'pop$'), Identifier(u'format.pages')]), FunctionLiteral([String(u''), Identifier(u'format.pages'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.vol.bracedyear.num.pages')],
  [Identifier(u'volume'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([String(u' \\pervolumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u"There's a volume but no year in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), QuotedVar(u'skip$'), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u' \\peryearformat {'), Identifier(u'year'), Identifier(u'*'), Identifier(u'add.extra.label'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'month'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u', '), Identifier(u'month'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'number'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u', \\pernumberformat {'), Identifier(u'number'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'pages'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'duplicate$'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'pop$'), Identifier(u'format.pages')]), FunctionLiteral([String(u''), Identifier(u'format.pages'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.chapter.pages')],
  [Identifier(u'chapter'),
   Identifier(u'empty$'),
   QuotedVar(u'format.pages'),
   FunctionLiteral([Identifier(u'type'), Identifier(u'empty$'), FunctionLiteral([String(u'\\unskip.\\,-- \\bibchapterlongname')]), FunctionLiteral([String(u'\\unskip.\\,-- '), Identifier(u'type'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'chapter'), Identifier(u'tie.or.space.connect'), Identifier(u'pages'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'format.pages'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.booktitleaddon')],
  [Identifier(u'booktitle'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'booktitleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'booktitleaddon')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.incoll.editor.booktitle')],
  [Identifier(u'booktitle'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u'\\incolledformat {}{}{'), Identifier(u'booktitle'), Identifier(u'incollbooktitlemarkup'), Identifier(u'format.booktitleaddon'), Identifier(u'*'), Identifier(u'*'), String(u'}{}'), Identifier(u'*'), Identifier(u'booktitleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'\\incolledformat {}{}{'), Identifier(u'booktitle'), Identifier(u'incollbooktitlemarkup'), Identifier(u'format.booktitleaddon'), Identifier(u'*'), Identifier(u'*'), String(u'}{'), Identifier(u'*'), Identifier(u'volume'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'booktitleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u'\\incolledformat {'), Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'editor'), Identifier(u'format.editor.names'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'editortype'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'num.names$'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'{\\edfont {\\editorsname}}{'), Identifier(u'*')]), FunctionLiteral([String(u'{\\edfont {\\editorname}}{'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'{\\edfont {('), Identifier(u'*'), Identifier(u'editortype'), Identifier(u'*'), String(u')}}{'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'booktitle'), Identifier(u'incollbooktitlemarkup'), Identifier(u'*'), Identifier(u'format.booktitleaddon'), Identifier(u'*'), String(u'}{}'), Identifier(u'*'), Identifier(u'booktitleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'\\incolledformat {'), Identifier(u'*'), Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'editor'), Identifier(u'format.editor.names'), String(u'}'), Identifier(u'*'), Identifier(u'*'), Identifier(u'editortype'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'num.names$'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'{\\edfont {\\editorsname}}{'), Identifier(u'*')]), FunctionLiteral([String(u'{\\edfont {\\editorname}}{'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'{\\edfont {('), Identifier(u'*'), Identifier(u'editortype'), Identifier(u'*'), String(u')}}{'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$'), Identifier(u'booktitle'), Identifier(u'incollbooktitlemarkup'), Identifier(u'*'), Identifier(u'format.booktitleaddon'), Identifier(u'*'), String(u'}{'), Identifier(u'volume'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'booktitleaddon'), Identifier(u'empty$'), FunctionLiteral([String(u'{} '), Identifier(u'*')]), FunctionLiteral([String(u'{1} '), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.tr.number.jur')],
  [Identifier(u'type'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'number'), Identifier(u'empty$'), FunctionLiteral([String(u' -- \\technicalreportname {} ')]), FunctionLiteral([String(u'~('), Identifier(u'number'), Identifier(u'*'), String(u').\\,-- \\technicalreportname {} '), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'number'), Identifier(u'empty$'), FunctionLiteral([String(u' -- '), Identifier(u'type'), Identifier(u'*')]), FunctionLiteral([String(u'~('), Identifier(u'number'), Identifier(u'*'), String(u').\\,-- '), Identifier(u'type'), Identifier(u'*'), String(u' '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.article.crossref.bracedyear')],
  [Identifier(u'key'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'journal'), Identifier(u'empty$'), FunctionLiteral([String(u'Need key or journal for '), Identifier(u'cite$'), Identifier(u'*'), String(u' to crossref '), Identifier(u'*'), Identifier(u'crossref'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([String(u'\\bibJTsep\\bibjtfont {'), Identifier(u'journal'), Identifier(u'*'), Identifier(u'check.punct.instead.of.add.period.art'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'volume'), Identifier(u'empty$'), FunctionLiteral([String(u'No volume in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), FunctionLiteral([String(u' \\pervolumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'year'), Identifier(u'empty$'), FunctionLiteral([String(u'No year in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$')]), FunctionLiteral([String(u'\\peryearformat {'), Identifier(u'year'), Identifier(u'*'), Identifier(u'add.extra.label'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'pages'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'duplicate$'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'pop$'), Identifier(u'format.pages')]), FunctionLiteral([Identifier(u'format.pages'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([String(u''), Identifier(u'key'), Identifier(u'*')]),
   Identifier(u'if$'),
   String(u'\\ \\protect\\jbcrossrefchecked {'),
   Identifier(u'*'),
   Identifier(u'crossref'),
   Identifier(u'*'),
   String(u'}\\unskip'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.article.crossref')],
  [Identifier(u'key'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'journal'), Identifier(u'empty$'), FunctionLiteral([String(u'Need key or journal for '), Identifier(u'cite$'), Identifier(u'*'), String(u' to crossref '), Identifier(u'*'), Identifier(u'crossref'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([String(u'\\bibJTsep\\bibjtfont {'), Identifier(u'journal'), Identifier(u'*'), Identifier(u'check.punct.instead.of.add.period.art'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([String(u''), Identifier(u'key'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'year'), Identifier(u'*')]),
   Identifier(u'if$'),
   String(u' \\protect\\jbcrossrefchecked {'),
   Identifier(u'crossref'),
   Identifier(u'*'),
   String(u'}'),
   Identifier(u'*')]],
 [u'FUNCTION',
  [Identifier(u'format.book.crossref')],
  [Identifier(u'editor'),
   Identifier(u'empty$'),
   Identifier(u'editor'),
   Identifier(u'field.or.null'),
   Identifier(u'author'),
   Identifier(u'field.or.null'),
   Identifier(u'='),
   Identifier(u'or'),
   FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'series'), Identifier(u'empty$'), FunctionLiteral([String(u'Need editor, key, or series for '), Identifier(u'cite$'), Identifier(u'*'), String(u' to crossref '), Identifier(u'*'), Identifier(u'crossref'), Identifier(u'*'), Identifier(u'warning$'), String(u''), Identifier(u'*')]), FunctionLiteral([String(u''), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'key'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([String(u''), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'volume'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'Empty volume in '), Identifier(u'cite$'), Identifier(u'*'), String(u"'s crossref of "), Identifier(u'*'), Identifier(u'crossref'), Identifier(u'*'), Identifier(u'warning$'), String(u''), String(u' \\protect\\jbcrossrefchecked {'), Identifier(u'*'), Identifier(u'crossref'), Identifier(u'*'), String(u'}\\unskip'), Identifier(u'*')]),
   FunctionLiteral([String(u' \\protect\\jbcrossrefchecked['), Identifier(u'*'), Identifier(u'volume'), Identifier(u'*'), String(u']{'), Identifier(u'*'), Identifier(u'crossref'), String(u'}\\unskip'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.incoll.inproc.crossref')],
  [String(u' \\protect\\jbincollcrossref {'),
   Identifier(u'*'),
   Identifier(u'crossref'),
   Identifier(u'*'),
   String(u'}'),
   Identifier(u'*'),
   Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u'{}'), Identifier(u'*')]),
   FunctionLiteral([String(u'{1}'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'format.pages')]],
 [u'FUNCTION',
  [Identifier(u'format.editors.organization')],
  [Identifier(u'organization'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'type$'), String(u'misc'), Identifier(u'='), FunctionLiteral([Identifier(u'organization')]), FunctionLiteral([Identifier(u'author'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u' '), Identifier(u'organization'), Identifier(u'*'), String(u' \\organizationname {}'), Identifier(u'*')]), FunctionLiteral([String(u'; '), Identifier(u'organization'), Identifier(u'*'), String(u' \\organizationname {}'), Identifier(u'*')]), Identifier(u'if$')]), FunctionLiteral([String(u'; '), Identifier(u'organization'), Identifier(u'*'), String(u' \\organizationname {}'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.address.organization.manual')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'address'), Identifier(u'output'), Identifier(u'part.of.sentence'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u'\\bibbdsep {}'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$')]), QuotedVar(u'skip$'), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'output'), Identifier(u'part.of.sentence'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u'\\bibbdsep {}'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'address'), Identifier(u'output'), Identifier(u'part.of.sentence')]), FunctionLiteral([Identifier(u'address'), String(u'\\bpubaddr {} '), Identifier(u'*'), Identifier(u'organization'), Identifier(u'*'), Identifier(u'output'), Identifier(u'part.of.sentence')]), Identifier(u'if$'), Identifier(u'year'), Identifier(u'empty$'), Identifier(u'not'), FunctionLiteral([String(u'\\bibbdsep {}'), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'article')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.artperiodincoll.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'journal'), Identifier(u'article.in.journal'), Identifier(u'output.nonnull'), Identifier(u'new.sentence'), Identifier(u'format.vol.year.num.pages'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'format.article.crossref'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited.artperiod'),
   Identifier(u'output'),
   Identifier(u'check.missing.pages'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'commented')],
  [Identifier(u'output.bibitem'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'format.founders')]), FunctionLiteral([Identifier(u'format.founders'), Identifier(u'format.editors'), String(u'editor'), Identifier(u'output.check')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'format.founders'), Identifier(u'output.nonnull')]), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'format.founders'), Identifier(u'format.editors'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.btitle.vol'), String(u'title'), Identifier(u'output.check')]),
   FunctionLiteral([Identifier(u'format.btitle'), String(u'title'), Identifier(u'output.check')]),
   Identifier(u'if$'),
   Identifier(u'format.volumetitle'),
   Identifier(u'output'),
   Identifier(u'format.edition'),
   Identifier(u'output'),
   Identifier(u'format.address.publisher.year'),
   String(u'publisher'),
   Identifier(u'output.check'),
   Identifier(u'format.update'),
   Identifier(u'new.sentence'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.series.number'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'format.book.crossref'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.howcited.comment'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'periodical')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.artperiodincoll.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'journal'), Identifier(u'article.in.journal'), Identifier(u'output.nonnull'), Identifier(u'new.sentence'), Identifier(u'format.vol.bracedyear.num.pages'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'new.sentence'), Identifier(u'format.article.crossref.bracedyear'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited.artperiod'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'book')],
  [Identifier(u'output.bibitem'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([String(u''), String(u'author and editor'), Identifier(u'output.check')]), FunctionLiteral([Identifier(u'format.editors'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'output.nonnull')]), FunctionLiteral([Identifier(u'format.authors'), String(u'\\jbtiafed {'), Identifier(u'format.editors'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.btitle.vol'), String(u'title'), Identifier(u'output.check')]),
   FunctionLiteral([Identifier(u'format.btitle'), String(u'title'), Identifier(u'output.check')]),
   Identifier(u'if$'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   Identifier(u'not'),
   Identifier(u'editor'),
   Identifier(u'empty$'),
   Identifier(u'not'),
   Identifier(u'and'),
   FunctionLiteral([String(u'\\jbedafti {\\edbyname {} '), Identifier(u'editor'), Identifier(u'*'), String(u','), Identifier(u'*'), Identifier(u'*'), String(u'} '), Identifier(u'*')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$'),
   Identifier(u'make.translators'),
   Identifier(u'output'),
   Identifier(u'format.volumetitle'),
   Identifier(u'output'),
   Identifier(u'format.edition'),
   Identifier(u'output'),
   Identifier(u'format.address.publisher.year'),
   String(u'publisher'),
   Identifier(u'output.check'),
   Identifier(u'new.sentence'),
   Identifier(u'format.juradiss.book'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.series.number'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'format.book.crossref'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.totalpages'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'inbook')],
  [Identifier(u'output.bibitem'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'format.editors'), String(u'author and editor'), Identifier(u'output.check')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'output.nonnull')]), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'format.editors'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'chapter'), Identifier(u'empty$'), FunctionLiteral([String(u"There's no chapter in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u''), Identifier(u'*')]), FunctionLiteral([Identifier(u'type'), Identifier(u'empty$'), FunctionLiteral([String(u'\\Bibchaptername{}')]), FunctionLiteral([Identifier(u'type')]), Identifier(u'if$'), Identifier(u'chapter'), Identifier(u'tie.or.space.connect'), String(u' In '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'format.btitle.vol.inbook'), String(u'title'), Identifier(u'output.check'), Identifier(u'make.translators'), Identifier(u'output'), Identifier(u'format.volumetitle'), Identifier(u'output'), Identifier(u'format.edition'), Identifier(u'output'), Identifier(u'format.address.publisher.year'), String(u'publisher'), Identifier(u'output.check'), Identifier(u'new.sentence'), Identifier(u'format.series.number'), Identifier(u'output'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.pages'), String(u'pages'), Identifier(u'output.check'), Identifier(u'format.note'), Identifier(u'format.isbn.issn'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'chapter'), Identifier(u'empty$'), FunctionLiteral([String(u"There's no chapter in "), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u''), Identifier(u'*'), Identifier(u'format.btitle.vol.inbook'), String(u'title'), Identifier(u'output.check')]), FunctionLiteral([Identifier(u'type'), Identifier(u'empty$'), FunctionLiteral([String(u'\\Bibchaptername{}')]), FunctionLiteral([Identifier(u'type')]), Identifier(u'if$'), Identifier(u'chapter'), Identifier(u'tie.or.space.connect'), String(u''), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'format.volumetitle'), Identifier(u'output'), Identifier(u'format.book.crossref'), Identifier(u'output.nonnull'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.pages'), String(u'pages'), Identifier(u'output.check'), Identifier(u'format.note')]),
   Identifier(u'if$'),
   Identifier(u'part.of.sentence'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'incollection')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.artperiodincoll.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'make.translators'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.incoll.editor.booktitle'), String(u'booktitle'), Identifier(u'output.check'), Identifier(u'format.volumetitle'), Identifier(u'output'), Identifier(u'format.edition'), Identifier(u'output'), Identifier(u'format.address.publisher.year'), String(u'publisher'), Identifier(u'output.check'), Identifier(u'new.sentence'), Identifier(u'format.series.number'), Identifier(u'output'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.isbn.issn'), Identifier(u'output'), Identifier(u'part.of.sentence'), Identifier(u'format.chapter.pages'), Identifier(u'output'), Identifier(u'format.note')]),
   FunctionLiteral([Identifier(u'format.volumetitle'), Identifier(u'output'), Identifier(u'format.incoll.inproc.crossref'), Identifier(u'output.nonnull'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.note')]),
   Identifier(u'if$'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'check.missing.pages'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'inproceedings')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.artperiodincoll.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.incoll.editor.booktitle'), String(u'booktitle'), Identifier(u'output.check'), Identifier(u'address'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'new.sentence.checka'), Identifier(u'organization'), Identifier(u'output'), Identifier(u'part.of.sentence'), Identifier(u'format.address.publisher.year'), Identifier(u'output')]), FunctionLiteral([Identifier(u'format.address.publisher.year'), String(u'publisher'), Identifier(u'output.check')]), Identifier(u'if$'), Identifier(u'new.sentence'), Identifier(u'series'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'format.series.number'), Identifier(u'output')]), Identifier(u'if$'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.note'), Identifier(u'format.isbn.issn'), Identifier(u'output'), Identifier(u'part.of.sentence'), Identifier(u'format.pages'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'format.incoll.inproc.crossref'), Identifier(u'output.nonnull'), Identifier(u'format.url'), Identifier(u'output'), Identifier(u'format.note')]),
   Identifier(u'if$'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION', [Identifier(u'conference')], [Identifier(u'inproceedings')]],
 [u'FUNCTION',
  [Identifier(u'manual')],
  [Identifier(u'output.bibitem'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\bibnf{'), Identifier(u'organization'), Identifier(u'*'), String(u'} {} {} {} {}'), Identifier(u'*'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'format.authors'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.btitle'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'format.edition'),
   Identifier(u'output'),
   Identifier(u'format.address.organization.manual'),
   Identifier(u'format.date'),
   Identifier(u'output'),
   Identifier(u'pages'),
   Identifier(u'set.period.dash.check'),
   Identifier(u'format.pages.book'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'mastersthesis')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.btitle'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'format.thesis'),
   Identifier(u'output'),
   Identifier(u'set.comma.pages.check'),
   Identifier(u'pages'),
   Identifier(u'new.sentence.checka'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'phdthesis')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.btitle'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'format.thesis'),
   Identifier(u'output'),
   Identifier(u'set.comma.pages.check'),
   Identifier(u'pages'),
   Identifier(u'new.sentence.checka'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'jurthesis')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.btitle'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'format.thesis'),
   Identifier(u'output'),
   Identifier(u'set.comma.pages.check'),
   Identifier(u'pages'),
   Identifier(u'new.sentence.checka'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'booklet')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'format.howpublished.address.year'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'misc')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.title'),
   Identifier(u'output'),
   Identifier(u'format.howpublished.address.year'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'proceedings')],
  [Identifier(u'output.bibitem'),
   Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\biblnfont {'), Identifier(u'organization'), Identifier(u'*'), String(u' \\organizationname}'), Identifier(u'*'), Identifier(u'output')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'format.editors'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.btitle'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'new.sentence'),
   Identifier(u'editor'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'format.proceed.organization'), Identifier(u'output')]),
   Identifier(u'if$'),
   Identifier(u'new.sentence'),
   Identifier(u'format.series.number'),
   Identifier(u'output.nonnull'),
   Identifier(u'volume'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u''), Identifier(u'output.nonnull')]),
   FunctionLiteral([String(u'\\volumeformat {'), Identifier(u'volume'), Identifier(u'*'), String(u'} '), Identifier(u'*'), String(u'volume'), Identifier(u'output.check')]),
   Identifier(u'if$'),
   Identifier(u'format.address.publisher.year'),
   String(u'publisher'),
   Identifier(u'output.check'),
   Identifier(u'pages'),
   Identifier(u'set.period.dash.check'),
   Identifier(u'format.pages.book'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'techreport')],
  [Identifier(u'output.bibitem'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'format.editors'), String(u'author and editor'), Identifier(u'output.check')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'output.nonnull')]), FunctionLiteral([Identifier(u'format.authors'), Identifier(u'format.editors'), Identifier(u'output.nonnull')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.title'),
   String(u'title'),
   Identifier(u'output.check'),
   Identifier(u'institution'),
   Identifier(u'new.sentence.checka'),
   Identifier(u'format.address.publisher.year'),
   Identifier(u'output'),
   Identifier(u'number'),
   Identifier(u'new.sentence.checka'),
   Identifier(u'format.tr.number.jur'),
   String(u'number'),
   Identifier(u'output.check'),
   Identifier(u'pages'),
   Identifier(u'set.period.dash.check'),
   Identifier(u'format.pages.book'),
   Identifier(u'output'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'www')],
  [Identifier(u'output.bibitem'),
   Identifier(u'format.authors'),
   String(u'author'),
   Identifier(u'output.check'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'format.naked.url'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION',
  [Identifier(u'lexicon')],
  [Identifier(u'output.bibitem'),
   Identifier(u'set.after.author.sep'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.btitle.vol'), String(u'title'), Identifier(u'output.check')]),
   FunctionLiteral([Identifier(u'format.btitle'), String(u'title'), Identifier(u'output.check')]),
   Identifier(u'if$'),
   Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\edbyname{} '), Identifier(u'*'), Identifier(u'editor'), Identifier(u'format.editor.names'), String(u','), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]),
   FunctionLiteral([String(u'\\byname{} '), Identifier(u'author'), Identifier(u'format.names'), Identifier(u'*'), String(u','), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'make.translators'),
   Identifier(u'output'),
   Identifier(u'format.volumetitle'),
   Identifier(u'output'),
   Identifier(u'format.edition'),
   Identifier(u'output'),
   Identifier(u'format.address.publisher.year'),
   String(u'publisher'),
   Identifier(u'output.check'),
   Identifier(u'new.sentence'),
   Identifier(u'format.juradiss.book'),
   Identifier(u'output'),
   Identifier(u'crossref'),
   Identifier(u'missing$'),
   FunctionLiteral([Identifier(u'format.series.number'), Identifier(u'output')]),
   FunctionLiteral([Identifier(u'format.book.crossref'), Identifier(u'output.nonnull')]),
   Identifier(u'if$'),
   Identifier(u'format.url'),
   Identifier(u'output'),
   Identifier(u'format.pages'),
   Identifier(u'output'),
   Identifier(u'format.totalpages'),
   Identifier(u'output'),
   Identifier(u'format.note'),
   Identifier(u'format.isbn.issn'),
   Identifier(u'output'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'STRINGS', [Identifier(u'last.archive'), Identifier(u'last.subarchive')]],
 [u'FUNCTION',
  [Identifier(u'init.last.archive')],
  [String(u''),
   QuotedVar(u'last.archive'),
   Identifier(u':='),
   String(u''),
   QuotedVar(u'last.subarchive'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'archival')],
  [Identifier(u'output.bibitem'),
   Identifier(u'archive'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u''), QuotedVar(u'last.archive'), Identifier(u':=')]),
   FunctionLiteral([Identifier(u'archive'), Identifier(u'last.archive'), Identifier(u'='), FunctionLiteral([String(u'} {'), Identifier(u'archive'), Identifier(u'format.name.sig'), Identifier(u'*'), String(u'} {} {\\jbsamearch{} '), Identifier(u'*'), Identifier(u'*')]), FunctionLiteral([String(u'\\bibanfont{'), Identifier(u'archive'), Identifier(u'*'), String(u'archive'), Identifier(u'output.check'), Identifier(u'shortarchive'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u' \\jbshortarchformat{'), Identifier(u'shortarchive'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'}'), Identifier(u'*'), String(u'} {'), Identifier(u'archive'), Identifier(u'format.name.sig'), Identifier(u'*'), String(u'} {} {\\jbnotsamearch{} '), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'archive'), QuotedVar(u'last.archive'), Identifier(u':=')]),
   Identifier(u'if$'),
   Identifier(u'subarchive'),
   Identifier(u'empty$'),
   FunctionLiteral([String(u''), QuotedVar(u'last.subarchive'), Identifier(u':=')]),
   FunctionLiteral([Identifier(u'subarchive'), Identifier(u'last.subarchive'), Identifier(u'='), QuotedVar(u'skip$'), FunctionLiteral([Identifier(u'subarchive'), Identifier(u'output'), Identifier(u'shortsubarchive'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u' \\jbshortsubarchformat{'), Identifier(u'shortsubarchive'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$'), String(u'\\jbsubarchsep{} '), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'subarchive'), QuotedVar(u'last.subarchive'), Identifier(u':=')]),
   Identifier(u'if$'),
   Identifier(u'sig1'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\jbarchsig {'), Identifier(u'*'), Identifier(u'subarchive'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'\\jbsamesubarchindent{} '), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'sig1'), Identifier(u'*'), Identifier(u'sig2'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig2'), Identifier(u'*'), Identifier(u'*'), Identifier(u'sig3'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig3'), Identifier(u'*'), Identifier(u'*'), Identifier(u'sig4'), Identifier(u'empty$'), QuotedVar(u'skip$'), FunctionLiteral([String(u'. '), Identifier(u'sig4'), Identifier(u'*'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$'), String(u'} {'), Identifier(u'*')]),
   Identifier(u'if$'),
   Identifier(u'archname'),
   Identifier(u'missing$'),
   FunctionLiteral([String(u'}'), Identifier(u'*')]),
   FunctionLiteral([Identifier(u'archname'), String(u'}'), Identifier(u'*'), Identifier(u'output')]),
   Identifier(u'if$'),
   Identifier(u'format.howcited'),
   Identifier(u'output'),
   Identifier(u'fin.entry.endnote')]],
 [u'FUNCTION', [Identifier(u'unpublished')], [Identifier(u'misc')]],
 [u'FUNCTION', [Identifier(u'default.type')], [Identifier(u'misc')]],
 [u'MACRO', [Identifier(u'jan')], [String(u'\\janname\\ ')]],
 [u'MACRO', [Identifier(u'feb')], [String(u'\\febname\\ ')]],
 [u'MACRO', [Identifier(u'mar')], [String(u'\\marname\\ ')]],
 [u'MACRO', [Identifier(u'apr')], [String(u'\\aprname\\ ')]],
 [u'MACRO', [Identifier(u'may')], [String(u'\\mayname\\ ')]],
 [u'MACRO', [Identifier(u'jun')], [String(u'\\junname\\ ')]],
 [u'MACRO', [Identifier(u'jul')], [String(u'\\julname\\ ')]],
 [u'MACRO', [Identifier(u'aug')], [String(u'\\augname\\ ')]],
 [u'MACRO', [Identifier(u'sep')], [String(u'\\sepname\\ ')]],
 [u'MACRO', [Identifier(u'oct')], [String(u'\\octname\\ ')]],
 [u'MACRO', [Identifier(u'nov')], [String(u'\\novname\\ ')]],
 [u'MACRO', [Identifier(u'dec')], [String(u'\\decname\\ ')]],
 [u'READ'],
 [u'FUNCTION',
  [Identifier(u'sortify')],
  [Identifier(u'purify$'), String(u'l'), Identifier(u'change.case$')]],
 [u'INTEGERS', [Identifier(u'len')]],
 [u'FUNCTION',
  [Identifier(u'chop.word')],
  [QuotedVar(u's'),
   Identifier(u':='),
   QuotedVar(u'len'),
   Identifier(u':='),
   Identifier(u's'),
   Integer(1),
   Identifier(u'len'),
   Identifier(u'substring$'),
   Identifier(u'='),
   FunctionLiteral([Identifier(u's'), Identifier(u'len'), Integer(1), Identifier(u'+'), Identifier(u'global.max$'), Identifier(u'substring$')]),
   QuotedVar(u's'),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.lab.names')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Identifier(u's'),
   Integer(1),
   String(u'{vv~}{ll}'),
   Identifier(u'format.name$'),
   Identifier(u's'),
   Identifier(u'num.names$'),
   Identifier(u'duplicate$'),
   Integer(2),
   Identifier(u'<'),
   QuotedVar(u'pop$'),
   FunctionLiteral([Identifier(u'duplicate$'), Identifier(u'duplicate$'), Integer(3), Identifier(u'>'), Identifier(u'swap$'), Identifier(u's'), Identifier(u'swap$'), String(u'{ff }{vv }{ll}{ jj}'), Identifier(u'format.name$'), String(u'others'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'pop$'), String(u'\\Bibetal'), Identifier(u'*')]), FunctionLiteral([Integer(2), Identifier(u'='), FunctionLiteral([String(u'\\jbbtasep '), Identifier(u'*'), Identifier(u's'), Integer(2), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*')]), FunctionLiteral([String(u'\\jbbfsasep '), Identifier(u'*'), Identifier(u's'), Integer(2), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*'), String(u'\\jbbstasep '), Identifier(u'*'), Identifier(u's'), Integer(3), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'missing$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\jbdy {'), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'format.editor.lab.names')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Identifier(u's'),
   Integer(1),
   String(u'{vv~}{ll}'),
   Identifier(u'format.name$'),
   Identifier(u's'),
   Identifier(u'num.names$'),
   Identifier(u'duplicate$'),
   Integer(2),
   Identifier(u'<'),
   QuotedVar(u'pop$'),
   FunctionLiteral([Identifier(u'duplicate$'), Identifier(u'duplicate$'), Integer(3), Identifier(u'>'), Identifier(u'swap$'), Identifier(u's'), Identifier(u'swap$'), String(u'{ff }{vv }{ll}{ jj}'), Identifier(u'format.name$'), String(u'others'), Identifier(u'='), Identifier(u'or'), FunctionLiteral([Identifier(u'pop$'), String(u'\\Bibetal'), Identifier(u'*')]), FunctionLiteral([Integer(2), Identifier(u'='), FunctionLiteral([String(u'\\jbbtesep '), Identifier(u'*'), Identifier(u's'), Integer(2), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*')]), FunctionLiteral([String(u'\\jbbfsesep '), Identifier(u'*'), Identifier(u's'), Integer(2), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*'), String(u'\\jbbstesep '), Identifier(u'*'), Identifier(u's'), Integer(3), String(u'{vv~}{ll}'), Identifier(u'format.name$'), Identifier(u'*')]), Identifier(u'if$')]), Identifier(u'if$')]),
   Identifier(u'if$'),
   Identifier(u'year'),
   Identifier(u'missing$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u'\\jbdy {'), Identifier(u'year'), Identifier(u'*'), String(u'}'), Identifier(u'*'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'author.key.label')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'cite$'), Integer(1), Integer(3), Identifier(u'substring$')]), QuotedVar(u'key'), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'format.lab.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'author.editor.key.label')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'cite$'), Integer(1), Integer(3), Identifier(u'substring$')]), QuotedVar(u'key'), Identifier(u'if$')]), FunctionLiteral([Identifier(u'editor'), Identifier(u'format.editor.lab.names')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'format.lab.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'editor.key.label')],
  [Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'cite$'), Integer(1), Integer(3), Identifier(u'substring$')]), QuotedVar(u'key'), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'format.editor.lab.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'calc.label')],
  [Identifier(u'type$'),
   String(u'book'),
   Identifier(u'='),
   Identifier(u'type$'),
   String(u'inbook'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'type$'),
   String(u'incollection'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'type$'),
   String(u'commented'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'type$'),
   String(u'lexicon'),
   Identifier(u'='),
   Identifier(u'or'),
   QuotedVar(u'author.editor.key.label'),
   FunctionLiteral([Identifier(u'type$'), String(u'proceedings'), Identifier(u'='), QuotedVar(u'editor.key.label'), QuotedVar(u'author.key.label'), Identifier(u'if$')]),
   Identifier(u'if$'),
   QuotedVar(u'label'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'calc.dummy.label')],
  [Identifier(u'type$'),
   String(u'book'),
   Identifier(u'='),
   Identifier(u'type$'),
   String(u'inbook'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'type$'),
   String(u'incollection'),
   Identifier(u'='),
   Identifier(u'or'),
   Identifier(u'type$'),
   String(u'commented'),
   Identifier(u'='),
   Identifier(u'or'),
   QuotedVar(u'author.editor.key.label'),
   FunctionLiteral([Identifier(u'type$'), String(u'proceedings'), Identifier(u'='), QuotedVar(u'editor.key.label'), QuotedVar(u'author.key.label'), Identifier(u'if$')]),
   Identifier(u'if$'),
   QuotedVar(u'dummy.label'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'sort.format.names')],
  [QuotedVar(u's'),
   Identifier(u':='),
   Integer(1),
   QuotedVar(u'nameptr'),
   Identifier(u':='),
   String(u''),
   Identifier(u's'),
   Identifier(u'num.names$'),
   QuotedVar(u'numnames'),
   Identifier(u':='),
   Identifier(u'numnames'),
   QuotedVar(u'namesleft'),
   Identifier(u':='),
   FunctionLiteral([Identifier(u'namesleft'), Integer(0), Identifier(u'>')]),
   FunctionLiteral([Identifier(u'nameptr'), Integer(1), Identifier(u'>'), FunctionLiteral([String(u'   '), Identifier(u'*')]), QuotedVar(u'skip$'), Identifier(u'if$'), Identifier(u's'), Identifier(u'nameptr'), String(u'{ll{ }}{  ff{ }}{ vv{ }}{  jj{ }}'), Identifier(u'format.name$'), QuotedVar(u't'), Identifier(u':='), Identifier(u'nameptr'), Identifier(u'numnames'), Identifier(u'='), Identifier(u't'), String(u'\\bibnf {others} {} {} {} {}'), Identifier(u'='), Identifier(u'and'), FunctionLiteral([String(u'\\Bibetal'), Identifier(u'*')]), FunctionLiteral([Identifier(u't'), Identifier(u'sortify'), Identifier(u'*')]), Identifier(u'if$'), Identifier(u'nameptr'), Integer(1), Identifier(u'+'), QuotedVar(u'nameptr'), Identifier(u':='), Identifier(u'namesleft'), Integer(1), Identifier(u'-'), QuotedVar(u'namesleft'), Identifier(u':=')]),
   Identifier(u'while$')]],
 [u'FUNCTION',
  [Identifier(u'sort.format.title')],
  [QuotedVar(u't'),
   Identifier(u':='),
   String(u'A '),
   Integer(2),
   String(u'An '),
   Integer(3),
   String(u'Der '),
   Integer(4),
   String(u'Die '),
   Integer(4),
   String(u'Das '),
   Integer(4),
   String(u'Ein '),
   Integer(4),
   String(u'Eine '),
   Integer(5),
   String(u'The '),
   Integer(4),
   Identifier(u't'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'chop.word'),
   Identifier(u'sortify'),
   Integer(1),
   Identifier(u'global.max$'),
   Identifier(u'substring$')]],
 [u'FUNCTION',
  [Identifier(u'author.sort')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'key'), Identifier(u'sortify')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'sort.format.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'author.editor.sort')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([String(u'')]), FunctionLiteral([Identifier(u'key'), Identifier(u'sortify')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'editor'), Identifier(u'sort.format.names')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'sort.format.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'editor.sort')],
  [Identifier(u'editor'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'key'), Identifier(u'empty$'), FunctionLiteral([String(u'to sort, need editor or key in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([Identifier(u'key'), Identifier(u'sortify')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'sort.format.names')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'archival.sort')],
  [Identifier(u'archive'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'shortarchive'), Identifier(u'empty$'), FunctionLiteral([String(u'to sort, need archive or shortarchive in '), Identifier(u'cite$'), Identifier(u'*'), Identifier(u'warning$'), String(u'')]), FunctionLiteral([Identifier(u'shortarchive'), Identifier(u'sortify')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'archive'), Identifier(u'sortify')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'presort')],
  [Identifier(u'calc.label'),
   Identifier(u'calc.dummy.label'),
   Identifier(u'dummy.label'),
   Identifier(u'sortify'),
   String(u' '),
   Identifier(u'*'),
   Identifier(u'sortkey'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'type$'), String(u'book'), Identifier(u'='), Identifier(u'type$'), String(u'incollection'), Identifier(u'='), Identifier(u'or'), Identifier(u'type$'), String(u'inbook'), Identifier(u'='), Identifier(u'or'), Identifier(u'type$'), String(u'commented'), Identifier(u'='), Identifier(u'or'), QuotedVar(u'author.editor.sort'), FunctionLiteral([Identifier(u'type$'), String(u'proceedings'), Identifier(u'='), QuotedVar(u'editor.sort'), FunctionLiteral([Identifier(u'type$'), String(u'archival'), Identifier(u'='), QuotedVar(u'archival.sort'), QuotedVar(u'author.sort'), Identifier(u'if$')]), Identifier(u'if$')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'sortkey'), Identifier(u'sort.format.names')]),
   Identifier(u'if$'),
   Identifier(u'type$'),
   String(u'archival'),
   Identifier(u'='),
   Identifier(u'not'),
   FunctionLiteral([String(u'    '), Identifier(u'*'), Identifier(u'year'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*'), String(u'    '), Identifier(u'*'), Identifier(u'title'), Identifier(u'field.or.null'), Identifier(u'sort.format.title'), Identifier(u'*')]),
   FunctionLiteral([String(u'    '), Identifier(u'*'), Identifier(u'subarchive'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*'), String(u'    '), Identifier(u'*'), Identifier(u'sig1'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*'), String(u'    '), Identifier(u'*'), Identifier(u'sig2'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*'), String(u'    '), Identifier(u'*'), Identifier(u'sig3'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*'), String(u'    '), Identifier(u'*'), Identifier(u'sig4'), Identifier(u'field.or.null'), Identifier(u'sortify'), Identifier(u'*')]),
   Identifier(u'if$'),
   Integer(1),
   Identifier(u'entry.max$'),
   Identifier(u'substring$'),
   QuotedVar(u'sort.label'),
   Identifier(u':='),
   Identifier(u'sort.label'),
   Identifier(u'*'),
   Integer(1),
   Identifier(u'entry.max$'),
   Identifier(u'substring$'),
   QuotedVar(u'sort.key$'),
   Identifier(u':=')]],
 [u'ITERATE', [Identifier(u'presort')]],
 [u'SORT'],
 [u'INTEGERS',
  [Identifier(u'last.extra.num'),
   Identifier(u'number.label'),
   Identifier(u'extra.extra.num')]],
 [u'FUNCTION',
  [Identifier(u'make.extra.label')],
  [Identifier(u'last.extra.num'),
   Integer(122),
   Identifier(u'<'),
   FunctionLiteral([Identifier(u'last.extra.num'), Integer(1), Identifier(u'+')]),
   FunctionLiteral([Identifier(u'extra.extra.num'), Integer(0), Identifier(u'='), FunctionLiteral([String(u'a'), Identifier(u'chr.to.int$')]), FunctionLiteral([Identifier(u'extra.extra.num'), Integer(1), Identifier(u'+')]), Identifier(u'if$'), QuotedVar(u'extra.extra.num'), Identifier(u':='), String(u'a'), Identifier(u'chr.to.int$')]),
   Identifier(u'if$'),
   QuotedVar(u'last.extra.num'),
   Identifier(u':='),
   Identifier(u'extra.extra.num'),
   Integer(0),
   Identifier(u'='),
   FunctionLiteral([Identifier(u'last.extra.num'), Identifier(u'int.to.chr$')]),
   FunctionLiteral([Identifier(u'extra.extra.num'), Identifier(u'int.to.chr$'), QuotedVar(u'extra.label'), Identifier(u':='), Identifier(u'extra.label'), Identifier(u'last.extra.num'), Identifier(u'int.to.chr$'), Identifier(u'*')]),
   Identifier(u'if$')]],
 [u'FUNCTION',
  [Identifier(u'forward.pass')],
  [Identifier(u'w'),
   Identifier(u'dummy.label'),
   Identifier(u'='),
   FunctionLiteral([Identifier(u'make.extra.label'), QuotedVar(u'extra.label'), Identifier(u':=')]),
   FunctionLiteral([String(u'a'), Identifier(u'chr.to.int$'), QuotedVar(u'last.extra.num'), Identifier(u':='), Integer(0), QuotedVar(u'extra.extra.num'), Identifier(u':='), String(u''), QuotedVar(u'extra.label'), Identifier(u':='), Identifier(u'dummy.label'), QuotedVar(u'w'), Identifier(u':=')]),
   Identifier(u'if$'),
   Identifier(u'number.label'),
   Integer(1),
   Identifier(u'+'),
   QuotedVar(u'number.label'),
   Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'reverse.pass')],
  [Identifier(u'x'),
   String(u'b'),
   Identifier(u'='),
   FunctionLiteral([String(u'a'), QuotedVar(u'extra.label'), Identifier(u':=')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$'),
   Identifier(u'extra.label'),
   QuotedVar(u'x'),
   Identifier(u':='),
   Identifier(u'extra.label'),
   Identifier(u'duplicate$'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([String(u''), Identifier(u'swap$'), Identifier(u'*')]),
   Identifier(u'if$'),
   QuotedVar(u'extra.label'),
   Identifier(u':='),
   Identifier(u'dummy.label'),
   Identifier(u'extra.label'),
   Identifier(u'*'),
   QuotedVar(u'dummy.label'),
   Identifier(u':=')]],
 [u'ITERATE', [Identifier(u'forward.pass')]],
 [u'REVERSE', [Identifier(u'reverse.pass')]],
 [u'FUNCTION',
  [Identifier(u'bib.sort.order')],
  [Identifier(u'sort.label'), QuotedVar(u'sort.key$'), Identifier(u':=')]],
 [u'ITERATE', [Identifier(u'bib.sort.order')]],
 [u'SORT'],
 [u'FUNCTION',
  [Identifier(u'set.current.authors')],
  [Identifier(u'author'),
   Identifier(u'empty$'),
   FunctionLiteral([Identifier(u'editor'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'organization'), Identifier(u'empty$'), FunctionLiteral([Identifier(u'cite$'), QuotedVar(u'current-authors'), Identifier(u':=')]), FunctionLiteral([Identifier(u'organization'), QuotedVar(u'current-authors'), Identifier(u':=')]), Identifier(u'if$')]), FunctionLiteral([Identifier(u'editor'), Identifier(u'format.names'), Integer(1), Identifier(u'entry.max$'), Identifier(u'substring$'), QuotedVar(u'current-authors'), Identifier(u':=')]), Identifier(u'if$')]),
   FunctionLiteral([Identifier(u'author'), Identifier(u'format.names'), Integer(1), Identifier(u'entry.max$'), Identifier(u'substring$'), QuotedVar(u'current-authors'), Identifier(u':=')]),
   Identifier(u'if$')]],
 [u'STRINGS', [Identifier(u'previous-authors')]],
 [u'FUNCTION',
  [Identifier(u'initialize.previous.authors')],
  [String(u''), QuotedVar(u'previous-authors'), Identifier(u':=')]],
 [u'FUNCTION',
  [Identifier(u'mark.repeat.authors')],
  [Identifier(u'current-authors'),
   Identifier(u'previous-authors'),
   Identifier(u'='),
   FunctionLiteral([Integer(1), QuotedVar(u'repeat-authors'), Identifier(u':=')]),
   QuotedVar(u'skip$'),
   Identifier(u'if$'),
   Identifier(u'current-authors'),
   QuotedVar(u'previous-authors'),
   Identifier(u':=')]],
 [u'ITERATE', [Identifier(u'set.current.authors')]],
 [u'EXECUTE', [Identifier(u'initialize.previous.authors')]],
 [u'ITERATE', [Identifier(u'mark.repeat.authors')]],
 [u'EXECUTE', [Identifier(u'initialize.previous.authors')]],
 [u'REVERSE', [Identifier(u'mark.repeat.authors')]],
 [u'FUNCTION',
  [Identifier(u'begin.bib')],
  [Identifier(u'preamble$'),
   Identifier(u'empty$'),
   QuotedVar(u'skip$'),
   FunctionLiteral([Identifier(u'preamble$'), Identifier(u'write$'), Identifier(u'newline$')]),
   Identifier(u'if$'),
   String(u'%'),
   Identifier(u'write$'),
   Identifier(u'newline$'),
   String(u'% This bibliography was produced by using jurabib.bst'),
   Identifier(u'write$'),
   Identifier(u'newline$'),
   String(u'%'),
   Identifier(u'write$'),
   Identifier(u'newline$'),
   String(u'\\begin{thebibliography}{}'),
   Identifier(u'write$'),
   Identifier(u'newline$')]],
 [u'EXECUTE', [Identifier(u'begin.bib')]],
 [u'EXECUTE', [Identifier(u'init.state.consts')]],
 [u'ITERATE', [Identifier(u'call.type$')]],
 [u'FUNCTION',
  [Identifier(u'end.bib')],
  [Identifier(u'newline$'),
   String(u'\\end{thebibliography}'),
   Identifier(u'write$'),
   Identifier(u'newline$')]],
 [u'EXECUTE', [Identifier(u'end.bib')]]]
